Given one or multiple paths to files produced by a PULSE multi-channel or a PULSE one-channel system (https://electricblue.eu/pulse) from a single experiment: [1] check pulse files for inconsistencies and read/merge all data, [2] split across time windows, [3] interpolate and smooth to optimize the dataset, [4] compute the heart rate frequency for each channel/window, and [5] facilitate quality control, summarising and plotting. Heart rate frequency is calculated using the Automatic Multi-scale Peak Detection algorithm proposed by Felix Scholkmann and team. For more details see Scholkmann et al (2012) tools:::Rd_expr_doi("10.3390/a5040588"). Check original code at https://github.com/ig248/pyampd. ElectricBlue is a non-profit technology transfer startup creating research-oriented solutions for the scientific community (https://electricblue.eu).
Maintainer: Rui Seabra ruisea@gmail.com (ORCID)
Authors:
Fernando Lima fplima@gmail.com (ORCID)