Learn R Programming

heartbeatr (version 1.0.0)

pulse_halve: Halves heart beat frequencies computed by pulse_heart

Description

Halves the heart beat frequency computed by pulse_heart when double peaks have been detected by pulse_correct. Note that the correction cannot be reverted (if just testing, store as a different variable). The associated stats are recalculated. This function is used by pulse_correct, it is not immediately usable as standalone.

Usage

pulse_halve(hr)

Value

A tibble with as many rows as the one provided as input, but with data, hz, n, sd, and ci adjusted accordingly.

Arguments

hr

a tibble as the one used as input to pulse_doublecheck(), but with the additional column d_f, which flags rows where heart beat frequencies need to be halved. All rows supplied are halved, so input should be a filtered version of the full dataset.

See Also

  • pulse_doublecheck() is the function within the heartbeatr-package that uses pulse_halve

  • PULSE() is a wrapper function that executes all the steps needed to process PULSE data at once, including the identification and correction of possible heart rate doublings